% vypocet delky a azimutu na elipsoidu WGS 84 (druha geodeticka uloha)
% (c) Martin Setnicka, 26.3.2009
clc; % vycisti command window

%% ZADANI [] [m] =========================================================
fA = dms2rad([   49  9 57.177   ]); % zem. sirka bodu A [  ' " ]
lA = dms2rad([   12 27 43.765   ]); % zem. delka bodu A [  ' " ]
fB = dms2rad([   59  9 57.177   ]); % zem. sirka bodu B [  ' " ]
lB = dms2rad([   22 27 43.765   ]); % zem. delka bodu B [  ' " ]
vizualizace = 1; % vizualizace = 1, pro vykresleni zeme

%% RESENI =================================================================
% WGS 84, nebo pouzit fci [a e] = almanac('earth','wgs84')
a = 6378137;               % m
b = 6356752.31425;         % m
e = sqrt( (a^2-b^2)/a^2 );

% vzdalenost |AB|, azimut z A na B
[dist_AB, az_AB] = distance(fA,lA,fB,lB,[a e],'rad');
fprintf('|AB| = % 10.4f m\n', dist_AB);
fprintf('azAB ='); rad2dms(az_AB);

%% VIZUALIZACE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if vizualizace

    % prevod na stupne
    ro = 180/pi;

    % nastaveni zobrazeni
    cla
    axesm('globe', 'Grid','on', 'GLineWidth', 2);
    axis off; hold on % vypnuti zobrazeni os; zakaz prepisovani novymi objekty
    view(100+lA*ro, fA*ro) % pohled (azimut, elevace)
    load topo % nacteni dat povrchu
    meshm(topo,topolegend,[90 180]) % zobrazeni povrchu na globus
    demcmap(topo) % prirazeni barev vyskam
    previewmap % zobrazeni pro tisk


    % rovnik
    [lat,long] = track1('gc',0,0,90);
    plotm(lat,long,'k--','LineWidth',3)
    % nulty polednik
    [lat,long] = track1('gc',0,0,0,[-90 90]);
    plotm(lat,long,'k--','LineWidth',3)

    % geodetika
    [lat,long] = track2('gc', fA*ro, lA*ro, fB*ro, lB*ro);
    plotm(lat,long,'y','LineWidth',3)
    % body
    plotm(fA*ro, lA*ro, 'rx', 'MarkerSize',10,'LineWidth',3)
    plotm(fB*ro, lB*ro, 'rx', 'MarkerSize',10,'LineWidth',3)

end
